Peptide Forest
=============

Peptide Forest is a machine learning based tool for semisupervised integration of multiple peptide identification search engines.


Contributors
------------

* T. Ranff
* M. Dennison
* J. Bédorf
* S. Schulze
* N. Zinn
* M. Bantscheff
* J.J.R.M. van Heugten
* C. Fufezan